import React from "react";
import { useStartServer, useStopServer, useDeleteServer } from "@mcl/queries";
import Box from "@mui/material/Box";
import Card from "@mui/material/Card";
import CardActions from "@mui/material/CardActions";
import CardContent from "@mui/material/CardContent";
import Chip from "@mui/material/Chip";
import IconButton from "@mui/material/IconButton";
import Typography from "@mui/material/Typography";

import StopIcon from "@mui/icons-material/Stop";
import TerminalIcon from "@mui/icons-material/Terminal";
import PlayArrowIcon from "@mui/icons-material/PlayArrow";
import DeleteForeverIcon from "@mui/icons-material/DeleteForever";
import EditIcon from "@mui/icons-material/Edit";
import FolderIcon from "@mui/icons-material/Folder";
import { Link } from "react-router-dom";

export default function ServerCard(props) {
  const { server, openRcon } = props;
  const { name, id, metrics, ftpAvailable, serverAvailable, services } = server;
  const startServer = useStartServer(id);
  const stopServer = useStopServer(id);
  const deleteServer = useDeleteServer(id);
  function toggleRcon() {
    if (!services.includes("server")) return;
    openRcon();
  }

  return (
    <Card className="server-card">
      <CardContent className="server-card-header server-card-element">
        <Typography
          gutterBottom
          variant="h5"
          component="div"
          className="server-card-title"
        >
          {name}
        </Typography>
        {metrics && (
          <Box className="server-card-metrics">
            <Typography
              gutterBottom
              variant="body2"
              component="div"
              className="server-card-metrics-info"
            >
              CPU: {metrics.cpu}
            </Typography>
            <Typography
              gutterBottom
              variant="body2"
              component="div"
              className="server-card-metrics-info"
            >
              MEM: {metrics.memory}MB
            </Typography>
          </Box>
        )}
        <Chip
          label={
            services.includes("server")
              ? serverAvailable
                ? "Online"
                : "Starting"
              : "Offline"
          }
          color={
            services.includes("server")
              ? serverAvailable
                ? "success"
                : "info"
              : "error"
          }
          className="server-card-status-indicator"
        />
      </CardContent>
      <div className="server-card-actions-wrapper">
        <CardActions className="server-card-actions server-card-element">
          {services.includes("server") && (
            <IconButton
              color="error"
              aria-label="Stop Server"
              onClick={stopServer}
              size="large"
            >
              <StopIcon />
            </IconButton>
          )}
          {!services.includes("server") && (
            <IconButton
              color="success"
              aria-label="Start Server"
              onClick={startServer}
              size="large"
            >
              <PlayArrowIcon />
            </IconButton>
          )}
          <IconButton
            color="primary"
            aria-label="RCON"
            onClick={toggleRcon}
            size="large"
            disabled={!services.includes("server")}
          >
            <TerminalIcon />
          </IconButton>
          <IconButton
            color="primary"
            aria-label="Edit"
            size="large"
            component={Link}
            to={`/mcl/edit?server=${id}`}
            disabled={services.includes("server")}
          >
            <EditIcon />
          </IconButton>
          <IconButton
            color="info"
            aria-label="Files"
            size="large"
            component={Link}
            to={`/mcl/files?server=${id}`}
            disabled={!ftpAvailable}
          >
            <FolderIcon />
          </IconButton>
          <IconButton
            color="error"
            aria-label="Delete Server"
            onClick={deleteServer}
            size="large"
          >
            <DeleteForeverIcon />
          </IconButton>
        </CardActions>
      </div>
    </Card>
  );
}
