import { useState, useEffect } from "react";
import { useSearchParams } from "react-router-dom";

const tokenStorageName = "cairoAuthToken";
const tokenQuery = "cairoAuthToken";

const verifyAuth = (authToken) =>
  fetch("/api/auth/verify", {
    headers: { Authorization: `Bearer ${authToken}` },
  })
    .then((res) => res.status === 200)
    .catch(() => false);

export function useCairoAuth() {
  const [authToken, setAuthToken] = useState(
    localStorage.getItem(tokenStorageName),
  );
  const [auth, setAuth] = useState(false);
  const [searchParams, setSearchParams] = useSearchParams();

  useEffect(() => {
    if (!authToken) return;
    verifyAuth(authToken).then((authorized) => {
      if (!authorized) localStorage.removeItem(tokenStorageName);
      setAuth(authorized);
    });
  }, [authToken]);

  useEffect(() => {
    const webToken = searchParams.get(tokenQuery);
    if (!webToken) return;
    localStorage.setItem(tokenStorageName, webToken);
    searchParams.delete(tokenQuery);
    setAuthToken(webToken);
    setSearchParams(searchParams);
  }, [searchParams]);

  return auth;
}

export function getAuthTokenFromStorage() {
  return localStorage.getItem(tokenStorageName);
}

export function cairoAuthHeader() {
  return { Authorization: `Bearer ${getAuthTokenFromStorage()}` };
}
